@@ -44,7 +44,7 @@ def on_message(client, obj, msg):
     global callback_dit
     topic = msg.topic
     try:
-        callback_dit[topic](json.loads(str(msg.payload, encoding="utf-8")), str(client._client_id, encoding='utf-8'))
+        threading.Thread(target=callback, args=(topic, msg, client), daemon=True).start()
     except Exception as ex:
         print(ex)
         keys = callback_dit.keys()
@@ -62,11 +62,15 @@ def on_message(client, obj, msg):
                         isThisTopic = False
                         break
             if isThisTopic:
-                callback_dit[item](json.loads(str(msg.payload, encoding="utf-8")), topic)
+                threading.Thread(target=callback, args=(item, msg, client), daemon=True).start()
                 break
 
 
-def callback():
+def callback(topic, msg, client):
+    msg = str(msg.payload.decode("utf-8"))
+    while type(msg) is str:
+        msg = json.loads(msg)
+    callback_dit[topic](msg, topic)
     pass
 
 
@@ -128,9 +132,13 @@ class Dxr_Subscriber:
 # 定义一个订阅者类的解释器
 class dxr_subscriber:
 
-    def __init__(self, topic):
+    def __init__(self, msg):
+        # 如果msg的类型是str,则将msg赋值给self.topic
+        if isinstance(msg, str):
+            self.topic = msg
+        else:
+            self.topic = msg.topic
         self.func = None
-        self.topic = topic
 
     def __call__(self, func):
         # 将函数绑定到解释器上
@@ -138,7 +146,6 @@ class dxr_subscriber:
         Dxr_Subscriber(self.topic, self.func)
 
 
-
 class Dxr_Publisher:
     def __init__(self, topic):
         global publish_dit, topic_list_str_pub, topic_list_str_sub
@@ -159,7 +166,7 @@ class Dxr_Publisher:
 
     def publish(self, msg):
         if self.data_type:
-            self.mqttc.publish(self.topic, str(msg), qos=0)
+            self.mqttc.publish(self.topic, msg.get_json(), qos=0)
         else:
             self.mqttc.publish(self.topic, json.dumps(msg), qos=0)
 
